@@ -1,5 +1,11 @@
 #![allow(dead_code)]
-#![allow(clippy::let_unit_value, clippy::match_same_arms)]
+#![allow(
+    clippy::derive_partial_eq_without_eq,
+    clippy::extra_unused_type_parameters,
+    clippy::let_underscore_untyped,
+    clippy::let_unit_value,
+    clippy::match_same_arms
+)]
 
 #[remain::sorted]
 #[derive(PartialEq)]
@@ -44,7 +50,7 @@ fn test_let() {
     let value = TestEnum::A;
 
     #[sorted]
-    let _ = match value {
+    let () = match value {
         TestEnum::A => {}
         #[remain::unsorted]
         TestEnum::Ignored => {}
